from typing import Optional

from pydantic import BaseModel, EmailStr, Field, validator


# Shared properties
class UserBase(BaseModel):
    email: Optional[EmailStr] = None
    username: Optional[str] = None
    is_active: Optional[bool] = True
    is_superuser: bool = False
    full_name: Optional[str] = None


# Properties to receive on user creation
class UserCreate(UserBase):
    email: EmailStr
    username: str
    password: str = Field(..., min_length=8)
    
    @validator("username")
    def username_alphanumeric(cls, v):
        if not v.isalnum():
            raise ValueError("Username must be alphanumeric")
        return v


# Properties to receive on user update
class UserUpdate(UserBase):
    password: Optional[str] = None


# Properties to return to client
class User(UserBase):
    id: int

    class Config:
        orm_mode = True


# Properties properties stored in JWT token
class UserInDB(User):
    hashed_password: str

    class Config:
        orm_mode = True